@@ -1,4 +1,4 @@
-## $Id: VectorValued.pm 5770 2011-08-31 22:07:03Z moocow $
+## $Id: VectorValued.pm 6820 2013-09-24 11:15:50Z moocow $
 ##
 ## File: PDL::VectorValued.pm
 ## Author: Bryan Jurish <moocow@cpan.org>
@@ -20,6 +20,7 @@ our @EXPORT_OK =
    (@PDL::VectorValued::Utils::EXPORT_OK), ##-- inherited
    qw(vv_uniqvec),
    qw(rleND rldND),
+   qw(vv_indx),
   );
 our %EXPORT_TAGS =
   (
@@ -73,7 +74,7 @@ functions to higher-order PDLs which treat vectors as "data values".
 
 =for sig
 
-  Signature: (int v(N,M); [o]vu(N,MU))
+  Signature: (v(N,M); [o]vu(N,MU))
 
 =for ref
 
@@ -206,6 +207,34 @@ sub rldND {
   return $data;
 }
 
+##======================================================================
+## pod: Functions: datatype utilities
+=pod
+
+=head1 Datatype Utilities
+
+=cut
+
+##----------------------------------------------------------------------
+## vv_indx()
+=pod
+
+=head2 vv_indx
+
+=for sig
+
+  Signature: vv_indx()
+
+=for ref
+
+Returns PDL::Type subclass used for indices.
+If built with PDL E<lt> v2.007, this should return C<PDL::long>, otherwise C<PDL::indx>.
+
+=cut
+
+sub vv_indx {
+  return defined(&PDL::indx) ? PDL::indx(@_) : PDL::long(@_);
+}
 
 1; ##-- make perl happy
 
